DebugLockManager

Trait DebugLockManager 

pub trait DebugLockManager: LockManager + Debug { }
Trait marker to bound LockManager with Debug for use inside the public API.

This is not a user-implemented trait; it is a convenience alias for LockManager + std::fmt::Debug so adapters can be boxed and passed to the builder.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors