pub trait DebugOwnershipOracle: OwnershipOracle + Debug { }Expand description
Trait marker to bound OwnershipOracle with Debug for use inside the public API.
pub trait DebugOwnershipOracle: OwnershipOracle + Debug { }Trait marker to bound OwnershipOracle with Debug for use inside the public API.