pub trait DebugSmokeTestRunner: SmokeTestRunner + Debug { }Expand description
Trait marker to bound SmokeTestRunner with Debug for use inside the public API.
pub trait DebugSmokeTestRunner: SmokeTestRunner + Debug { }Trait marker to bound SmokeTestRunner with Debug for use inside the public API.