Re-exports
pub use errors::*;pub use ids::*;pub use mount::*;pub use ownership::*;pub use plan::*;pub use preflight::*;pub use report::*;pub use rescue::*;pub use safepath::*;
Modules
- errors
- Error types used across Switchyard.
- ids
- Deterministic
UUIDv5identifiers for plans and actions. - mount
- Data-only mount types used across the crate.
- ownership
- Data-only type for ownership information of a filesystem path.
Centralized under
crate::typesfor cross-layer reuse. - plan
- preflight
- report
- rescue
- Data-only rescue status and error types used across the crate.
- safepath