Function switchyard::threads::single_pool_two_to_one [−][src]
pub fn single_pool_two_to_one<'a>(
input: ThreadAllocationInput,
thread_name: Option<&'a str>
) -> impl Iterator<Item = ThreadAllocationOutput> + 'a
A two thread per core, single pool thread configuration.
- Creates a single pool of jobs with index 0.
- Two threads per logical core.
- Each set of two threads assigned to a different core.
input is the result of calling thread_info.